﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class FiremanInsideInteraction : Interactable
{
    [SerializeField] ThinkingCloud cloud;
    [SerializeField] Dog dog;
    [SerializeField] StraightMovement movement;
    [SerializeField] GameObject axe;
    Animator anim;

    private void Start()
    {
        anim = GetComponent<Animator>();
        dog = FindObjectOfType<Dog>();
    }

    public override void Interact()
    {
        if (dog.inventory.element != ImageLibrary.instance.photo)
        {
            cloud.EnqueueImageToShow(ImageLibrary.instance.question);
            return;
        }
        dog.inventory.Remove();
        StartCoroutine(FinishInteraction());
    }

    private IEnumerator FinishInteraction()
    {
        dog.movement.enabled = false;

        yield return new WaitForSeconds(1);

        cloud.EnqueueImageToShow(ImageLibrary.instance.photo);
        cloud.EnqueueImageToShow(ImageLibrary.instance.alert);

        yield return new WaitUntil(() => !cloud.gameObject.activeSelf);

        yield return new WaitForSeconds(1);

        renderer.flipX = true;
        yield return new WaitForSeconds(0.25f);
        axe.SetActive(false);
        yield return new WaitForSeconds(0.25f);
        renderer.flipX = false;

        movement.enabled = true;
        anim.SetFloat("speed", 1);
        yield return new WaitForSeconds(0.5f);
        dog.movement.enabled = true;
        SetPostInteraction();
    }

    [SerializeField] List<GameObject> showAfterInteraction;
    [SerializeField] List<GameObject> destroyAfterInteraction;
    private void SetPostInteraction()
    {
        foreach (var o in showAfterInteraction) o.SetActive(true);
        foreach (var o in destroyAfterInteraction) Destroy(o);
    }
}
