﻿using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Tutorial_Require_Meat : WorldEventsManager
{
    [SerializeField] GameObject boxesContainer;
    [SerializeField] GameObject correctBox;
    [SerializeField] GameObject obstacle;

    void Start()
    {
        IEnumerable<Interactable> interactables = boxesContainer.GetComponentsInChildren<Interactable>();
        foreach (var interactable in interactables)
        {
            if (interactable.gameObject == correctBox)
            {
                interactable.OnInteractSuccess += CorrectBoxOpened;
            }
            else
            {
                interactable.OnInteractSuccess += IncorrectBoxOpened;
            }
        }

        EventOnTriggerEnter exitEvent = obstacle.GetComponentInChildren<EventOnTriggerEnter>();
        exitEvent.OnTriggerEnter += TryingToLeave;
    }

    private void CorrectBoxOpened()
    {
        Destroy(obstacle);
        DisableAllInteractiveBoxes();
        dog.think.ThinkIn(ImageLibrary.instance.happy);
        dog.think.ThinkIn(ImageLibrary.instance.dots);
        dog.think.ThinkIn(ImageLibrary.instance.home);
        StartCoroutine(DisableMovementUntilStopsThinking());
    }

    private void DisableAllInteractiveBoxes()
    {
        foreach (Interactable interactable in boxesContainer.GetComponentsInChildren<Interactable>())
        {
            interactable.OnInteractSuccess -= CorrectBoxOpened;
            interactable.OnInteractSuccess -= IncorrectBoxOpened;
            interactable.OnInteractSuccess += JustThinkInHome;
        }
    }

    private void JustThinkInHome()
    {
        dog.think.ThinkIn(ImageLibrary.instance.home);
    }

    private void IncorrectBoxOpened()
    {
        dog.think.ThinkIn(ImageLibrary.instance.angry);
        dog.think.ThinkIn(ImageLibrary.instance.smell);
        dog.think.ThinkIn(ImageLibrary.instance.meat);
        StartCoroutine(DisableMovementUntilStopsThinking());
    }

    IEnumerator DisableMovementUntilStopsThinking()
    {
        dog.movement.enabled = false;
        dog.interact.enabled = false;
        yield return new WaitUntil(() => !dog.think.IsThinking());
        dog.movement.enabled = true;
        dog.interact.enabled = true;
    }

    private void TryingToLeave()
    {
        if (dog.think.IsThinking()) return;
        dog.think.ThinkIn(ImageLibrary.instance.meat);
    }

}
