﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using UnityEngine;

public class AbilitySmell : MonoBehaviour
{
    private Dictionary<Smells, float> smellDistance = new Dictionary<Smells, float>();

    private new CircleCollider2D collider;
    private List<Smells> smeltObjects = new List<Smells>();

    public event Action<Smells> OnObjectAdded;
    public event Action<Smells> OnObjectRemoved;
    public event Action<Smells> OnSmellDistanceUpdated;

    void Start()
    {
        collider = GetComponent<CircleCollider2D>();
    }

    void Update()
    {
        //UpdateSmeltValues();
    }

    private void OnTriggerEnter2D(Collider2D collision)
    {
        Smells smellComponent = collision.GetComponent<Smells>();
        if (smellComponent == null) return;
        smeltObjects.Add(smellComponent);
        smellDistance.Add(smellComponent, 0);

        OnObjectAdded.SafeInvoke(smellComponent);

        UpdateSmeltValue(smellComponent);
    }

    private void UpdateSmeltValues()
    {
        foreach (Smells smeltObject in smeltObjects)
        {
            UpdateSmeltValue(smeltObject);
        }
    }

    private void OnTriggerStay2D(Collider2D collision)
    {
        Smells smellComponent = collision.GetComponent<Smells>();
        if (smellComponent == null) return;
        UpdateSmeltValue(smellComponent);
    }

    private void UpdateSmeltValue(Smells smellComponent)
    {
        smellDistance[smellComponent] = Vector2.Distance(smellComponent.transform.position, transform.position) / smellComponent.smellAmount;

        OnSmellDistanceUpdated.SafeInvoke(smellComponent);
    }

    public float GetSmeltDistance(Smells smellComponent)
    {
        return smellDistance[smellComponent];
    }

    private void OnTriggerExit2D(Collider2D collision)
    {
        Smells smellComponent = collision.GetComponent<Smells>();
        if (smellComponent == null) return;

        smellDistance.Remove(smellComponent);
        smeltObjects.Remove(smellComponent);

        OnObjectRemoved(smellComponent);
    }

    public float MaxSmellDistance
    {
        get
        {
            return collider.bounds.extents.x;
        }
    }
}
