﻿using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class BlackDogInteraction : Interactable
{
    [SerializeField] ThinkingCloud cloud;
    [SerializeField] Dog dog;
    [SerializeField] StraightMovement movement;
    Animator anim;

    private void Start()
    {
        anim = GetComponent<Animator>();
        dog = FindObjectOfType<Dog>();
    }

    public override void Interact()
    {
        if (dog.inventory.element != ImageLibrary.instance.bone)
        {
            cloud.EnqueueImageToShow(ImageLibrary.instance.bone);
            return;
        }
        dog.inventory.Remove();
        StartCoroutine(FinishInteraction());
    }

    private IEnumerator FinishInteraction()
    {
        dog.movement.enabled = false;

        for (float time = 1.5f; time > 0.3f; time /= 3)
        {
            cloud.timeToShowEachImage = time;
            cloud.EnqueueImageToShow(ImageLibrary.instance.happy);
            cloud.EnqueueImageToShow(ImageLibrary.instance.bone);
            yield return new WaitUntil(() => !cloud.gameObject.activeSelf);
        }
        for (int i = 0; i < 20; i++)
        {
            cloud.timeToShowEachImage = 0.2f;
            cloud.EnqueueImageToShow(ImageLibrary.instance.happy);
            cloud.EnqueueImageToShow(ImageLibrary.instance.bone);
        }

        anim.speed = 2;
        anim.SetFloat("speed", 1);
        SetPostInteraction();
        yield return new WaitForSeconds(2);
        movement.enabled = true;
        yield return new WaitForSeconds(1);
        dog.movement.enabled = true;
        yield return new WaitForSeconds(2);
        Destroy(gameObject);
    }

    [SerializeField] List<GameObject> showAfterInteraction;
    [SerializeField] List<GameObject> destroyAfterInteraction;
    private void SetPostInteraction()
    {
        foreach (var o in showAfterInteraction) o.SetActive(true);
        foreach (var o in destroyAfterInteraction) Destroy(o);
    }
}
