﻿using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class SmellVisualizer : MonoBehaviour
{
    [SerializeField] private Image iconPrefab;

    private Dictionary<Smells, RectTransform> iconForObject = new Dictionary<Smells, RectTransform>();

    private AbilitySmell abilitySmell;

    private RectTransform rect;

    void Start()
    {
        rect = GetComponent<RectTransform>();

        abilitySmell = FindObjectOfType<AbilitySmell>();
        abilitySmell.OnObjectAdded += ObjectAddedHandler;
        abilitySmell.OnObjectRemoved += ObjectRemovedHandler;
        abilitySmell.OnSmellDistanceUpdated += SmellDistanceUpdatedHandler;
    }

    private void ObjectAddedHandler(Smells obj)
    {
        SpriteRenderer smeltObjectImage = obj.GetComponent<SpriteRenderer>();
        Image newIcon = Instantiate(iconPrefab, transform);
        newIcon.gameObject.SetActive(true);
        newIcon.sprite = smeltObjectImage.sprite;
        RectTransform newIconRect = newIcon.GetComponent<RectTransform>();
        iconForObject[obj] = newIconRect;
        newIconRect.anchoredPosition = GetRandomPositionForIconRect(newIconRect);
    }

    private Vector2 GetRandomPositionForIconRect(RectTransform newIconRect)
    {
        float maxX = rect.sizeDelta.x / 2 - newIconRect.sizeDelta.x / 2;
        float maxY = rect.sizeDelta.y / 2 - newIconRect.sizeDelta.y / 2;
        return new Vector2(UnityEngine.Random.Range(-maxX, maxX), UnityEngine.Random.Range(-maxY, maxY));
    }

    private void SmellDistanceUpdatedHandler(Smells obj)
    {
        float scale = Mathf.Lerp(1f, 0.0f, abilitySmell.GetSmeltDistance(obj) / abilitySmell.MaxSmellDistance);
        iconForObject[obj].localScale = Vector3.one * scale;
    }

    private void ObjectRemovedHandler(Smells obj)
    {
        Destroy(iconForObject[obj].gameObject);
        iconForObject.Remove(obj);
    }

}
